use strict;
use warnings;
use Test::More;

use_ok 'Data::Object::String::Func';
use_ok 'Data::Object::String::Func::Append';
use_ok 'Data::Object::String::Func::Camelcase';
use_ok 'Data::Object::String::Func::Chomp';
use_ok 'Data::Object::String::Func::Chop';
use_ok 'Data::Object::String::Func::Concat';
use_ok 'Data::Object::String::Func::Contains';
use_ok 'Data::Object::String::Func::Defined';
use_ok 'Data::Object::String::Func::Hex';
use_ok 'Data::Object::String::Func::Index';
use_ok 'Data::Object::String::Func::Lc';
use_ok 'Data::Object::String::Func::Lcfirst';
use_ok 'Data::Object::String::Func::Length';
use_ok 'Data::Object::String::Func::Lines';
use_ok 'Data::Object::String::Func::Lowercase';
use_ok 'Data::Object::String::Func::Replace';
use_ok 'Data::Object::String::Func::Reverse';
use_ok 'Data::Object::String::Func::Rindex';
use_ok 'Data::Object::String::Func::Snakecase';
use_ok 'Data::Object::String::Func::Split';
use_ok 'Data::Object::String::Func::Strip';
use_ok 'Data::Object::String::Func::Titlecase';
use_ok 'Data::Object::String::Func::Trim';
use_ok 'Data::Object::String::Func::Uc';
use_ok 'Data::Object::String::Func::Ucfirst';
use_ok 'Data::Object::String::Func::Uppercase';
use_ok 'Data::Object::String::Func::Words';

ok 1 and done_testing;
