use strict;
use warnings;
use Test::More;

use_ok 'Data::Object::Number::Func';
use_ok 'Data::Object::Number::Func::Abs';
use_ok 'Data::Object::Number::Func::Atan2';
use_ok 'Data::Object::Number::Func::Cos';
use_ok 'Data::Object::Number::Func::Decr';
use_ok 'Data::Object::Number::Func::Defined';
use_ok 'Data::Object::Number::Func::Exp';
use_ok 'Data::Object::Number::Func::Hex';
use_ok 'Data::Object::Number::Func::Incr';
use_ok 'Data::Object::Number::Func::Int';
use_ok 'Data::Object::Number::Func::Log';
use_ok 'Data::Object::Number::Func::Mod';
use_ok 'Data::Object::Number::Func::Neg';
use_ok 'Data::Object::Number::Func::Pow';
use_ok 'Data::Object::Number::Func::Sin';
use_ok 'Data::Object::Number::Func::Sqrt';

ok 1 and done_testing;
