use strict;
use warnings;
use Test::More;

use_ok 'Data::Object::Array::Func';
use_ok 'Data::Object::Array::Func::All';
use_ok 'Data::Object::Array::Func::Any';
use_ok 'Data::Object::Array::Func::Clear';
use_ok 'Data::Object::Array::Func::Count';
use_ok 'Data::Object::Array::Func::Defined';
use_ok 'Data::Object::Array::Func::Delete';
use_ok 'Data::Object::Array::Func::Each';
use_ok 'Data::Object::Array::Func::EachKey';
use_ok 'Data::Object::Array::Func::EachNValues';
use_ok 'Data::Object::Array::Func::EachValue';
use_ok 'Data::Object::Array::Func::Empty';
use_ok 'Data::Object::Array::Func::Eq';
use_ok 'Data::Object::Array::Func::Exists';
use_ok 'Data::Object::Array::Func::First';
use_ok 'Data::Object::Array::Func::Ge';
use_ok 'Data::Object::Array::Func::Get';
use_ok 'Data::Object::Array::Func::Grep';
use_ok 'Data::Object::Array::Func::Gt';
use_ok 'Data::Object::Array::Func::Hash';
use_ok 'Data::Object::Array::Func::Hashify';
use_ok 'Data::Object::Array::Func::Head';
use_ok 'Data::Object::Array::Func::Invert';
use_ok 'Data::Object::Array::Func::Iterator';
use_ok 'Data::Object::Array::Func::Join';
use_ok 'Data::Object::Array::Func::Keyed';
use_ok 'Data::Object::Array::Func::Keys';
use_ok 'Data::Object::Array::Func::Last';
use_ok 'Data::Object::Array::Func::Le';
use_ok 'Data::Object::Array::Func::Length';
use_ok 'Data::Object::Array::Func::List';
use_ok 'Data::Object::Array::Func::Lt';
use_ok 'Data::Object::Array::Func::Map';
use_ok 'Data::Object::Array::Func::Max';
use_ok 'Data::Object::Array::Func::Min';
use_ok 'Data::Object::Array::Func::Ne';
use_ok 'Data::Object::Array::Func::None';
use_ok 'Data::Object::Array::Func::Nsort';
use_ok 'Data::Object::Array::Func::One';
use_ok 'Data::Object::Array::Func::Pairs';
use_ok 'Data::Object::Array::Func::PairsArray';
use_ok 'Data::Object::Array::Func::PairsHash';
use_ok 'Data::Object::Array::Func::Part';
use_ok 'Data::Object::Array::Func::Pop';
use_ok 'Data::Object::Array::Func::Push';
use_ok 'Data::Object::Array::Func::Random';
use_ok 'Data::Object::Array::Func::Reverse';
use_ok 'Data::Object::Array::Func::Rnsort';
use_ok 'Data::Object::Array::Func::Rotate';
use_ok 'Data::Object::Array::Func::Rsort';
use_ok 'Data::Object::Array::Func::Set';
use_ok 'Data::Object::Array::Func::Shift';
use_ok 'Data::Object::Array::Func::Size';
use_ok 'Data::Object::Array::Func::Slice';
use_ok 'Data::Object::Array::Func::Sort';
use_ok 'Data::Object::Array::Func::Sum';
use_ok 'Data::Object::Array::Func::Tail';
use_ok 'Data::Object::Array::Func::Unique';
use_ok 'Data::Object::Array::Func::Unshift';
use_ok 'Data::Object::Array::Func::Values';

ok 1 and done_testing;
